@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,7 +12,7 @@
 #include "jobs/followupreminderfinishtaskjob.h"
 #include "jobs/followupreminderjob.h"
 
-#include <Akonadi/KMime/SpecialMailCollections>
+#include <Akonadi/SpecialMailCollections>
 
 #include <KConfig>
 #include <KConfigGroup>
@@ -183,7 +183,7 @@ QString FollowUpReminderManager::infoToStr(FollowUpReminder::FollowUpReminderInf
     infoStr += QStringLiteral("MessageId :%1\n").arg(info->messageId());
     infoStr += QStringLiteral("Subject :%1\n").arg(info->subject());
     infoStr += QStringLiteral("To :%1\n").arg(info->to());
-    infoStr += QStringLiteral("Dead Line :%1\n").arg(info->followUpReminderDate().toString());
+    infoStr += QStringLiteral("Deadline :%1\n").arg(info->followUpReminderDate().toString());
     infoStr += QStringLiteral("Answer received :%1\n").arg(info->answerWasReceived() ? QStringLiteral("true") : QStringLiteral("false"));
     infoStr += QStringLiteral("****************************************\n");
     return infoStr;
