@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -22,9 +22,16 @@ public:
     void setInfo(const QList<FollowUpReminder::FollowUpReminderInfo *> &info);
 
     void wakeUp();
+
+public Q_SLOTS:
+    void reject() override;
+
 Q_SIGNALS:
     void needToReparseConfiguration();
 
+protected:
+    void closeEvent(QCloseEvent *) override;
+
 private:
     void slotDBusNotificationsPropertiesChanged(const QString &interface, const QVariantMap &changedProperties, const QStringList &invalidatedProperties);
     void slotSave();
