@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -10,7 +10,7 @@
 #include <QObject>
 
 #include <Akonadi/Collection>
-#include <Akonadi/KMime/MarkAsCommand>
+#include <Akonadi/MarkAsCommand>
 
 class MarkAllMessagesAsReadInFolderAndSubFolderJob : public QObject
 {
