@@ -1,11 +1,11 @@
 /*
- * SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2011-2022 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-only
  */
 #pragma once
 
-#include <Akonadi/KMime/MessageModel>
+#include <Akonadi/MessageModel>
 #include <QHash>
 
 class KMSearchMessageModel : public Akonadi::MessageModel
