@@ -3,7 +3,7 @@
  * SPDX-FileCopyrightText: 1996-1998 Stefan Taferner <taferner@kde.org>
  * SPDX-FileCopyrightText: 2001 Aaron J. Seigo <aseigo@kde.org>
  * SPDX-FileCopyrightText: 2010 Till Adam <adam@kde.org>
- * SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2011-2022 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -16,6 +16,7 @@
 #include "kmkernel.h"
 #include "kmmainwidget.h"
 #include "kmsearchmessagemodel.h"
+#include "messagecore/stringutil.h"
 #include "searchdescriptionattribute.h"
 #include "searchpatternwarning.h"
 #include <MailCommon/FolderRequester>
@@ -37,12 +38,12 @@
 #include <Akonadi/PersistentSearchAttribute>
 #include <Akonadi/SearchCreateJob>
 #include <Akonadi/StandardActionManager>
-#include <AkonadiSearch/PIM/indexeditems.h>
 #include <KActionMenu>
 #include <KMessageBox>
 #include <KMime/KMimeMessage>
 #include <KStandardAction>
 #include <KStandardGuiItem>
+#include <PIM/indexeditems.h>
 #include <QIcon>
 #include <QSortFilterProxyModel>
 
@@ -320,7 +321,7 @@ void SearchWindow::activateFolder(const Akonadi::Collection &collection)
         if (collection.hasAttribute<Akonadi::SearchDescriptionAttribute>()) {
             currentFolderIsSearchFolder = true; // FIXME is there a better way to tell?
 
-            const auto *searchDescription = collection.attribute<Akonadi::SearchDescriptionAttribute>();
+            const auto searchDescription = collection.attribute<Akonadi::SearchDescriptionAttribute>();
             mSearchPattern.deserialize(searchDescription->description());
 
             const QList<Akonadi::Collection::Id> lst = searchDescription->listCollection();
@@ -484,9 +485,15 @@ void SearchWindow::doSearch()
         dlg.exec();
     }
 
+    auto config = KConfig(QStringLiteral("akonadi_indexing_agent"));
+    KConfigGroup cfg = config.group("General");
+    const bool respectDiacriticAndAccents = cfg.readEntry("respectDiacriticAndAccents", true);
+
     if (!mFolder.isValid()) {
-        qCDebug(KMAIL_LOG) << " create new folder " << mUi.mSearchFolderEdt->text();
-        auto searchJob = new Akonadi::SearchCreateJob(mUi.mSearchFolderEdt->text(), mQuery, this);
+        const QString searchString =
+            respectDiacriticAndAccents ? mUi.mSearchFolderEdt->text() : MessageCore::StringUtil::normalize(mUi.mSearchFolderEdt->text());
+        qCDebug(KMAIL_LOG) << " create new folder " << searchString;
+        auto searchJob = new Akonadi::SearchCreateJob(searchString, mQuery, this);
         searchJob->setSearchMimeTypes(QStringList() << QStringLiteral("message/rfc822"));
         searchJob->setSearchCollections(searchCollections);
         searchJob->setRecursive(recursive);
@@ -541,7 +548,7 @@ void SearchWindow::searchDone(KJob *job)
         // the server, for easy retrieval when editing it again
         const QByteArray search = mSearchPattern.serialize();
         Q_ASSERT(!search.isEmpty());
-        auto *searchDescription = mFolder.attribute<Akonadi::SearchDescriptionAttribute>(Akonadi::Collection::AddIfMissing);
+        auto searchDescription = mFolder.attribute<Akonadi::SearchDescriptionAttribute>(Akonadi::Collection::AddIfMissing);
         searchDescription->setDescription(search);
         if (mUi.mChkMultiFolders->isChecked()) {
             searchDescription->setBaseCollection(Akonadi::Collection());
